@@ -22,9 +22,9 @@ This module contains Google PubSub operators.
 
     MessageStoragePolicy
 """
-import warnings
 from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
 from google.cloud.pubsub_v1.types import (
     DeadLetterPolicy,
@@ -55,25 +55,23 @@ class PubSubCreateTopicOperator(BaseOperator):
 
         with DAG('successful DAG') as dag:
             (
-                PubSubTopicCreateOperator(project='my-project',
-                                             topic='my_new_topic')
-                >> PubSubTopicCreateOperator(project='my-project',
-                                             topic='my_new_topic')
+                PubSubCreateTopicOperator(project_id='my-project', topic='my_new_topic')
+                >> PubSubCreateTopicOperator(project_id='my-project', topic='my_new_topic')
             )
 
     The operator can be configured to fail if the topic already exists. ::
 
         with DAG('failing DAG') as dag:
             (
-                PubSubTopicCreateOperator(project='my-project',
-                                             topic='my_new_topic')
-                >> PubSubTopicCreateOperator(project='my-project',
-                                             topic='my_new_topic',
-                                             fail_if_exists=True)
+                PubSubCreateTopicOperator(project_id='my-project', topic='my_new_topic')
+                >> PubSubCreateTopicOperator(
+                    project_id='my-project',
+                    topic='my_new_topic',
+                    fail_if_exists=True,
+                )
             )
 
-    Both ``project`` and ``topic`` are templated so you can use
-    variables in them.
+    Both ``project_id`` and ``topic`` are templated so you can use Jinja templating in their values.
 
     :param project_id: Optional, the Google Cloud project ID where the topic will be created.
         If set to None or missing, the default project_id from the Google Cloud connection is used.
@@ -103,7 +101,6 @@ class PubSubCreateTopicOperator(BaseOperator):
         to complete. Note that if retry is specified, the timeout applies to each
         individual attempt.
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :param project: (Deprecated) the Google Cloud project ID where the topic will be created
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -132,22 +129,12 @@ class PubSubCreateTopicOperator(BaseOperator):
         labels: Optional[Dict[str, str]] = None,
         message_storage_policy: Union[Dict, MessageStoragePolicy] = None,
         kms_key_name: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
-        project: Optional[str] = None,
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
         **kwargs,
     ) -> None:
-        # To preserve backward compatibility
-        # TODO: remove one day
-        if project:
-            warnings.warn(
-                "The project parameter has been deprecated. You should pass the project_id parameter.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-            project_id = project
 
         super().__init__(**kwargs)
         self.project_id = project_id
@@ -192,8 +179,8 @@ class PubSubCreateSubscriptionOperator(BaseOperator):
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:PubSubCreateSubscriptionOperator`
 
-    By default, the subscription will be created in ``topic_project``. If
-    ``subscription_project`` is specified and the Google Cloud credentials allow, the
+    By default, the subscription will be created in ``project_id``. If
+    ``subscription_project_id`` is specified and the Google Cloud credentials allow, the
     Subscription can be created in a different project from its topic.
 
     By default, if the subscription already exists, this operator will
@@ -201,12 +188,16 @@ class PubSubCreateSubscriptionOperator(BaseOperator):
 
         with DAG('successful DAG') as dag:
             (
-                PubSubSubscriptionCreateOperator(
-                    topic_project='my-project', topic='my-topic',
-                    subscription='my-subscription')
-                >> PubSubSubscriptionCreateOperator(
-                    topic_project='my-project', topic='my-topic',
-                    subscription='my-subscription')
+                PubSubCreateSubscriptionOperator(
+                    project_id='my-project',
+                    topic='my-topic',
+                    subscription='my-subscription'
+                )
+                >> PubSubCreateSubscriptionOperator(
+                    project_id='my-project',
+                    topic='my-topic',
+                    subscription='my-subscription',
+                )
             )
 
     The operator can be configured to fail if the subscription already exists.
@@ -214,25 +205,27 @@ class PubSubCreateSubscriptionOperator(BaseOperator):
 
         with DAG('failing DAG') as dag:
             (
-                PubSubSubscriptionCreateOperator(
-                    topic_project='my-project', topic='my-topic',
-                    subscription='my-subscription')
-                >> PubSubSubscriptionCreateOperator(
-                    topic_project='my-project', topic='my-topic',
-                    subscription='my-subscription', fail_if_exists=True)
+                PubSubCreateSubscriptionOperator(
+                    project_id='my-project',
+                    topic='my-topic',
+                    subscription='my-subscription',
+                )
+                >> PubSubCreateSubscriptionOperator(
+                    project_id='my-project',
+                    topic='my-topic',
+                    subscription='my-subscription',
+                    fail_if_exists=True,
+                )
             )
 
     Finally, subscription is not required. If not passed, the operator will
     generated a universally unique identifier for the subscription's name. ::
 
         with DAG('DAG') as dag:
-            (
-                PubSubSubscriptionCreateOperator(
-                    topic_project='my-project', topic='my-topic')
-            )
+            PubSubCreateSubscriptionOperator(project_id='my-project', topic='my-topic')
 
-    ``topic_project``, ``topic``, ``subscription``, ``subscription_project_id`` and
-    ``impersonation_chain`` are templated so you can use variables in them.
+    ``project_id``, ``topic``, ``subscription``, ``subscription_project_id`` and
+    ``impersonation_chain`` are templated so you can use Jinja templating in their values.
 
     :param project_id: Optional, the Google Cloud project ID where the topic exists.
         If set to None or missing, the default project_id from the Google Cloud connection is used.
@@ -294,9 +287,6 @@ class PubSubCreateSubscriptionOperator(BaseOperator):
         to complete. Note that if retry is specified, the timeout applies to each
         individual attempt.
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :param topic_project: (Deprecated) the Google Cloud project ID where the topic exists
-    :param subscription_project: (Deprecated) the Google Cloud project ID where the subscription
-        will be created. If empty, ``topic_project`` will be used.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -336,34 +326,12 @@ class PubSubCreateSubscriptionOperator(BaseOperator):
         filter_: Optional[str] = None,
         dead_letter_policy: Optional[Union[Dict, DeadLetterPolicy]] = None,
         retry_policy: Optional[Union[Dict, RetryPolicy]] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
-        topic_project: Optional[str] = None,
-        subscription_project: Optional[str] = None,
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
         **kwargs,
     ) -> None:
-
-        # To preserve backward compatibility
-        # TODO: remove one day
-        if topic_project:
-            warnings.warn(
-                "The topic_project parameter has been deprecated. You should pass "
-                "the project_id parameter.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-            project_id = topic_project
-        if subscription_project:
-            warnings.warn(
-                "The project_id parameter has been deprecated. You should pass "
-                "the subscription_project parameter.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-            subscription_project_id = subscription_project
-
         super().__init__(**kwargs)
         self.project_id = project_id
         self.topic = topic
@@ -431,22 +399,16 @@ class PubSubDeleteTopicOperator(BaseOperator):
     not cause the DAG to fail. ::
 
         with DAG('successful DAG') as dag:
-            (
-                PubSubTopicDeleteOperator(project='my-project',
-                                             topic='non_existing_topic')
-            )
+            PubSubDeleteTopicOperator(project_id='my-project', topic='non_existing_topic')
 
     The operator can be configured to fail if the topic does not exist. ::
 
         with DAG('failing DAG') as dag:
-            (
-                PubSubTopicCreateOperator(project='my-project',
-                                             topic='non_existing_topic',
-                                             fail_if_not_exists=True)
+            PubSubDeleteTopicOperator(
+                project_id='my-project', topic='non_existing_topic', fail_if_not_exists=True,
             )
 
-    Both ``project`` and ``topic`` are templated so you can use
-    variables in them.
+    Both ``project_id`` and ``topic`` are templated so you can use Jinja templating in their values.
 
     :param project_id: Optional, the Google Cloud project ID in which to work (templated).
         If set to None or missing, the default project_id from the Google Cloud connection is used.
@@ -467,7 +429,6 @@ class PubSubDeleteTopicOperator(BaseOperator):
         to complete. Note that if retry is specified, the timeout applies to each
         individual attempt.
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :param project: (Deprecated) the Google Cloud project ID where the topic will be created
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -493,23 +454,12 @@ class PubSubDeleteTopicOperator(BaseOperator):
         fail_if_not_exists: bool = False,
         gcp_conn_id: str = 'google_cloud_default',
         delegate_to: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
-        project: Optional[str] = None,
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
         **kwargs,
     ) -> None:
-        # To preserve backward compatibility
-        # TODO: remove one day
-        if project:
-            warnings.warn(
-                "The project parameter has been deprecated. You should pass the project_id parameter.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-            project_id = project
-
         super().__init__(**kwargs)
         self.project_id = project_id
         self.topic = topic
@@ -551,24 +501,18 @@ class PubSubDeleteSubscriptionOperator(BaseOperator):
     not cause the DAG to fail. ::
 
         with DAG('successful DAG') as dag:
-            (
-                PubSubSubscriptionDeleteOperator(project='my-project',
-                                                    subscription='non-existing')
-            )
+            PubSubDeleteSubscriptionOperator(project_id='my-project', subscription='non-existing')
 
     The operator can be configured to fail if the subscription already exists.
 
     ::
 
         with DAG('failing DAG') as dag:
-            (
-                PubSubSubscriptionDeleteOperator(
-                     project='my-project', subscription='non-existing',
-                     fail_if_not_exists=True)
+            PubSubDeleteSubscriptionOperator(
+                project_id='my-project', subscription='non-existing', fail_if_not_exists=True,
             )
 
-    ``project``, and ``subscription`` are templated so you can use
-    variables in them.
+    ``project_id``, and ``subscription`` are templated so you can use Jinja templating in their values.
 
     :param project_id: Optional, the Google Cloud project ID in which to work (templated).
         If set to None or missing, the default project_id from the Google Cloud connection is used.
@@ -589,7 +533,6 @@ class PubSubDeleteSubscriptionOperator(BaseOperator):
         to complete. Note that if retry is specified, the timeout applies to each
         individual attempt.
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :param project: (Deprecated) the Google Cloud project ID where the topic will be created
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -615,23 +558,12 @@ class PubSubDeleteSubscriptionOperator(BaseOperator):
         fail_if_not_exists: bool = False,
         gcp_conn_id: str = 'google_cloud_default',
         delegate_to: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
-        project: Optional[str] = None,
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
         **kwargs,
     ) -> None:
-        # To preserve backward compatibility
-        # TODO: remove one day
-        if project:
-            warnings.warn(
-                "The project parameter has been deprecated. You should pass the project_id parameter.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-            project_id = project
-
         super().__init__(**kwargs)
         self.project_id = project_id
         self.subscription = subscription
@@ -679,14 +611,16 @@ class PubSubPublishMessageOperator(BaseOperator):
         m2 = {'data': b'Knock, knock'}
         m3 = {'attributes': {'foo': ''}}
 
-        t1 = PubSubPublishOperator(
-            project='my-project',topic='my_topic',
+        t1 = PubSubPublishMessageOperator(
+            project_id='my-project',
+            topic='my_topic',
             messages=[m1, m2, m3],
             create_topic=True,
-            dag=dag)
+            dag=dag,
+        )
 
-    ``project`` , ``topic``, and ``messages`` are templated so you can use
-    variables in them.
+    ``project_id``, ``topic``, and ``messages`` are templated so you can use Jinja templating
+    in their values.
 
     :param project_id: Optional, the Google Cloud project ID in which to work (templated).
         If set to None or missing, the default project_id from the Google Cloud connection is used.
@@ -707,7 +641,6 @@ class PubSubPublishMessageOperator(BaseOperator):
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :param project: (Deprecated) the Google Cloud project ID where the topic will be created
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -734,20 +667,9 @@ class PubSubPublishMessageOperator(BaseOperator):
         project_id: Optional[str] = None,
         gcp_conn_id: str = 'google_cloud_default',
         delegate_to: Optional[str] = None,
-        project: Optional[str] = None,
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
         **kwargs,
     ) -> None:
-        # To preserve backward compatibility
-        # TODO: remove one day
-        if project:
-            warnings.warn(
-                "The project parameter has been deprecated. You should pass the project_id parameter.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-            project_id = project
-
         super().__init__(**kwargs)
         self.project_id = project_id
         self.topic = topic
@@ -775,22 +697,20 @@ class PubSubPullOperator(BaseOperator):
     instead.
 
     .. seealso::
-        For more information on how to use this operator, take a look at the guide:
+        For more information on how to use this operator and the PubSubPullSensor, take a look at the guide:
         :ref:`howto/operator:PubSubPullSensor`
 
-    This sensor operator will pull up to ``max_messages`` messages from the
+    This operator will pull up to ``max_messages`` messages from the
     specified PubSub subscription. When the subscription returns messages,
-    the poke method's criteria will be fulfilled and the messages will be
-    returned from the operator and passed through XCom for downstream tasks.
+    the messages will be returned immediately from the operator and passed through XCom for downstream tasks.
 
     If ``ack_messages`` is set to True, messages will be immediately
     acknowledged before being returned, otherwise, downstream tasks will be
     responsible for acknowledging them.
 
-    ``project`` and ``subscription`` are templated so you can use
-    variables in them.
+    ``project_id `` and ``subscription`` are templated so you can use Jinja templating in their values.
 
-    :param project: the Google Cloud project ID for the subscription (templated)
+    :param project_id: the Google Cloud project ID for the subscription (templated)
     :param subscription: the Pub/Sub subscription name. Do not include the
         full subscription path.
     :param max_messages: The maximum number of messages to retrieve per
